summaryrefslogtreecommitdiff
path: root/web/share/js/kvm/mouse.js
diff options
context:
space:
mode:
Diffstat (limited to 'web/share/js/kvm/mouse.js')
-rw-r--r--web/share/js/kvm/mouse.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/web/share/js/kvm/mouse.js b/web/share/js/kvm/mouse.js
index 1c33e4c0..7a0a50f3 100644
--- a/web/share/js/kvm/mouse.js
+++ b/web/share/js/kvm/mouse.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
# KVMD - The main Pi-KVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
@@ -142,7 +142,7 @@ export function Mouse(__getResolution, __recordWsEvent) {
}
} else {
if (is_captured) {
- title = "Mouse captured, Pi-KVM offline";
+ title = "Mouse captured, PiKVM offline";
}
}
$("hid-mouse-led").className = led;
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #